@@ -12,6 +12,8 @@ from pathlib import Path
 import logging
 
 from easy_binary_file import EasyBinaryFile, load_single_value, dump_single_value, quick_dump_items, quick_load_items
+from quick_queue import QQueue
+
 
 
 try:
@@ -29,6 +31,7 @@ __test__ = {'import_test': """
 
 def sorted_in_disk(iterable,
                    key=None,
+                   value=None,
                    reverse=False,
 
                    tmp_dir=Path("sortInDiskTmps"),
@@ -43,9 +46,14 @@ def sorted_in_disk(iterable,
 
                    max_process=0,
                    queue_max_size=1000,
+                   size_bucket_list=None,
+                   min_size_bucket_list=10,
+                   max_size_bucket_list=None,
 
                    iter_multiprocessing=False,
                    iter_m_queue_max_size=1000,
+                   iter_min_size_bucket_list=10,
+                   iter_max_size_bucket_list=None,
 
                    logging_level=logging.WARNING):
     """
@@ -112,8 +120,11 @@ def sorted_in_disk(iterable,
     :param iterable: iterable to sort in disk
         This iterable should by a generator for big data due to memory RAM limitation.
     :param key: key specifies a function of one argument that is used to extract a comparison key from each element in
-        iterable (for example, key=str.lower or key=lambda e: e.split(",")[3]).
+        iterable (for example, key=str.lower or key=lambda e: e.split(",")[1]).
         The default value is None (compare the elements directly).
+    :param value: value specifies a function of one argument that is used to extract a value from each element in
+        iterable (for example, key=lambda e: e.split(",")[1:]).
+        The default value is None (value is full element).
     :param reverse: reverse is a boolean value.
         If set to True, then the list elements are sorted as if each comparison were reversed.
     :param tmp_dir: Path to dir where save temporal files. If None this create a folder and overwrite if
@@ -132,7 +143,7 @@ def sorted_in_disk(iterable,
         (only execute when count_insert_to_check is reached). If None, then not import psutil and then only
         check with count_insert_to_check. By default: 1024*1024*1024  # 1Gib
     :param ensure_space: True to ensure disk space but is slowly. If not space then process launch warning message
-        and wait for space. If False, then get and IOException if not enough space
+        and wait for space. If False, then get and IOException if not enough space. By defatul: False
     :param max_process: number of process to execute. If None then it is number of CPUs. By default: 0
     :param queue_max_size: (only if max_process!=0) max number of elements in queue. If None then is the max by default.
         By default: 1000
@@ -140,7 +151,19 @@ def sorted_in_disk(iterable,
         By default: False
     :param iter_m_queue_max_size: (only if enable_multiprocessing is True) max number of elements in queue. If None
         then is the max by default. By default: 1000
+    :param iter_min_size_bucket_list: (only if sensor is enabled) min size bucket list.
+                         Min == 1 and max == iter_max_size_bucket_list - 1. By default: 10
+    :param iter_max_size_bucket_list: (only if sensor is enabled) max size bucket list. If None is infinite.
+                                 By default: None
     :param logging_level: Level of log. Only to debug or to remove psutil warning. By default: logging.WARNING
+    :param size_bucket_list: None to enable sensor size bucket list (require maxsize>0). If a number is defined
+                             here then use this number to size_bucket_list and disable sensor. If maxsize<=0
+                             and size_bucket_list==None then size_bucket_list is default to 1000; other wise,
+                             if maxsize<=0 and size_bucket_list is defined, then use this number. By default: None
+    :param min_size_bucket_list: (only if sensor is enabled) min size bucket list.
+                                 Min == 1 and max == max_size_bucket_list - 1. By default: 10
+    :param max_size_bucket_list: (only if sensor is enabled) max size bucket list. If None is infinite.
+                                 By default: None
 
     :return: SortedInDisk object (you can iterate directly in for structure in same way as list)
 
@@ -152,15 +175,21 @@ def sorted_in_disk(iterable,
                         ensure_different_dirs=ensure_different_dirs,
                         iter_multiprocessing=iter_multiprocessing,
                         iter_m_queue_max_size=iter_m_queue_max_size,
+                        iter_min_size_bucket_list=iter_min_size_bucket_list,
+                        iter_max_size_bucket_list=iter_max_size_bucket_list,
                         logging_level=logging_level,
                         ).save_and_sort(iterable,
-                                        func_key_sort=key,
+                                        func_key=key,
+                                        func_value=value,
                                         reverse=reverse,
                                         max_process=max_process,
                                         count_insert_to_check=count_insert_to_check,
                                         max_process_size=max_process_size,
                                         queue_max_size=queue_max_size,
-                                        ensure_space=ensure_space)
+                                        ensure_space=ensure_space,
+                                        size_bucket_list=size_bucket_list,
+                                        min_size_bucket_list=min_size_bucket_list,
+                                        max_size_bucket_list=max_size_bucket_list)
 
 
 def _is_parent_process_killed():
@@ -281,12 +310,12 @@ def _mprocess(proxy_queue,
             try:
                 sort_key, value = proxy_queue.get(timeout=0.1)
                 times_waiting = 0
-
                 start_cursor_pos = f_full_data.get_cursor_position()
 
-                f_full_data.dump(value,
-                                 ensure_space=ensure_space,
-                                 fun_err_space=evt_err_space_dump)
+                if ensure_space:
+                    f_full_data.dump(value)
+                else:
+                    f_full_data.dump_ensure_space(value, fun_err_space=evt_err_space_dump)
 
                 try:
                     fpositions = dict_keysortable_fpositions[sort_key]
@@ -353,6 +382,7 @@ def _mprocess(proxy_queue,
                                                                                          os.getpid()))
             except Exception as err:
                 logging.error("[ERROR -> id:{} | ppid:{} | pid:{}]: {}".format(ipid, os.getppid(), os.getpid(), err))
+                raise
 
     total_bulk_counter += cache_bulk_counter
 
@@ -466,6 +496,7 @@ def _iter_get_data_from_files(dict_ipid_tup_full_list_parts, reverse=False):
 
 
 def _mprocess_iter(proxy_queue_iter,
+                   proxy_queue_iter_init_args,
                    proxy_start_event_iter,
                    proxy_end_event_iter,
 
@@ -481,7 +512,7 @@ def _mprocess_iter(proxy_queue_iter,
     :param proxy_end_event_iter: end flag process notification
     :param dict_ipid_tup_full_list_parts: dict with information about temporal files
     :param reverse: True to reverse sort. By default: False
-    :param logging_level:
+    :param logging_level: Level of log. Only to debug or to remove psutil warning. By default: logging.WARNING
     :return: None
     """
     logging.basicConfig(stream=sys.stderr, level=logging_level)
@@ -490,6 +521,8 @@ def _mprocess_iter(proxy_queue_iter,
     proxy_start_event_iter.set()
     gc.collect()
 
+    proxy_queue_iter.init(**proxy_queue_iter_init_args)
+
     if dict_ipid_tup_full_list_parts is not None:
         for tup_key_loadpickle in _iter_get_data_from_files(dict_ipid_tup_full_list_parts, reverse):
             loop_enable = True
@@ -505,6 +538,7 @@ def _mprocess_iter(proxy_queue_iter,
 
         logging.debug("[LOOP GETTER STOP -> ppid:{} | pid:{}]".format(os.getppid(), os.getpid()))
 
+    proxy_queue_iter.end()
     proxy_end_event_iter.set()
     gc.collect()
     logging.debug("[END GETTER -> ppid:{} | pid:{}]".format(os.getppid(), os.getpid()))
@@ -597,6 +631,9 @@ class SortedInDisk(object):
 
                  iter_multiprocessing=False,
                  iter_m_queue_max_size=1000,
+                 iter_size_bucket_list=None,
+                 iter_min_size_bucket_list=10,
+                 iter_max_size_bucket_list=None,
 
                  logging_level=logging.WARNING):
         """
@@ -612,14 +649,14 @@ class SortedInDisk(object):
 
         Quick simple use (Multiprocessor):
             sid = SortedInDisk().save_and_sort(iterator_with_data_to_sort,
-                                             func_key_sort=lambda line: line.split("|")[0])
+                                             func_key=lambda line: line.split("|")[0])
             for line_sorted in sid:
                 print(line_sorted)
 
         Multiprocessor declaration:
             sid = SortedInDisk(Path("C:\tmp_folder\"))\
                   .save_and_sort(iterator_with_data_to_sort,
-                                 func_key_sort=lambda line: line.split()[0])
+                                 func_key=lambda line: line.split()[0])
 
             Note: This is not blocking the current thread flow. Join when call to iter_with_key().
                   To explicit join call to: sid.join_multiprocess()
@@ -627,7 +664,7 @@ class SortedInDisk(object):
         Mono thread (current) declaration:
             sid = SortedInDisk(Path("C:\tmp_folder\"))\
                   .save_and_sort(iterator_with_data_to_sort,
-                                 func_key_sort=lambda line: line.split()[0],
+                                 func_key=lambda line: line.split()[0],
                                  max_process=0)
 
             Note: This is blocking the current thread flow until end.
@@ -653,6 +690,16 @@ class SortedInDisk(object):
             By default: False
         :param iter_m_queue_max_size: (only if enable_multiprocessing is True) max number of elements in queue. If None
             then is the max by default. By default: 1000
+        :param iter_size_bucket_list: None to enable sensor size bucket list (require maxsize>0). If a number is defined
+                                 here then use this number to iter_size_bucket_list and disable sensor. If maxsize<=0
+                                 and iter_size_bucket_list==None then iter_size_bucket_list is default to 1000; other
+                                 wise, if maxsize<=0 and iter_size_bucket_list is defined, then use this number.
+                                 By default: None
+        :param iter_min_size_bucket_list: (only if sensor is enabled) min size bucket list.
+                                     Min == 1 and max == iter_max_size_bucket_list - 1. By default: 10
+        :param iter_max_size_bucket_list: (only if sensor is enabled) max size bucket list. If None is infinite.
+                                     By default: None
+        :param logging_level: Level of log. Only to debug or to remove psutil warning. By default: logging.WARNING
         """
         self.logging_level = logging_level
         logging.basicConfig(stream=sys.stderr, level=self.logging_level)
@@ -674,6 +721,9 @@ class SortedInDisk(object):
 
         self.iter_multiprocessing = iter_multiprocessing
         self.iter_m_queue_max_size = iter_m_queue_max_size
+        self.iter_size_bucket_list = iter_size_bucket_list
+        self.iter_min_size_bucket_list = iter_min_size_bucket_list
+        self.iter_max_size_bucket_list = iter_max_size_bucket_list
 
     def tmp_paths(self, include_tmp_folder=True):
         dict_info = self.get_dict_saved_info()
@@ -745,7 +795,7 @@ class SortedInDisk(object):
 
     def save_and_sort_mono(self,
                            it_values,
-                           func_key_sort=None,
+                           func_key=None,
                            func_value=None,
                            reverse=False,
 
@@ -758,7 +808,7 @@ class SortedInDisk(object):
         Mono thread, this one execute in current thread.
 
         :param it_values: iterator of values
-        :param func_key_sort: function to extract the key of each value of it_values.
+        :param func_key: function to extract the key of each value of it_values.
             If None is full value of it_values. By default: None
         :param func_value: function to extract the value of each value of it_values.
             If None is full value of it_values. By default: None
@@ -772,11 +822,11 @@ class SortedInDisk(object):
             and wait for space. If False, then get and IOException if not enough space
         :return: self
         """
-        if func_key_sort is None:
-            def func_key_sort_default(key):
+        if func_key is None:
+            def func_key_default(key):
                 return key
 
-            func_key_sort = func_key_sort_default
+            func_key = func_key_default
 
         if func_value is None:
             def func_value_default(value):
@@ -829,13 +879,15 @@ class SortedInDisk(object):
             dict_info["multiprocessing"] = False
 
             for value in it_values:
-                mkey = func_key_sort(value)
+                mkey = func_key(value)
                 value = func_value(value)
 
                 start_cursor_pos = f_full_data_open.get_cursor_position()
-                f_full_data_open.dump(value,
-                                      ensure_space=ensure_space,
-                                      fun_err_space=evt_err_space_dump)
+
+                if ensure_space:
+                    f_full_data_open.dump(value)
+                else:
+                    f_full_data_open.dump_ensure_space(value, fun_err_space=evt_err_space_dump)
 
                 try:
                     fpositions = dict_keysortable_fpositions[mkey]
@@ -914,7 +966,10 @@ class SortedInDisk(object):
         """
         return self.iter_with_key(delete_to_end=self.delete_to_end,
                                   enable_multiprocessing=self.iter_multiprocessing,
-                                  queue_max_size=self.iter_m_queue_max_size)
+                                  queue_max_size=self.iter_m_queue_max_size,
+                                  size_bucket_list=self.iter_size_bucket_list,
+                                  min_size_bucket_list=self.iter_min_size_bucket_list,
+                                  max_size_bucket_list=self.iter_max_size_bucket_list)
 
     def values(self):
         """
@@ -923,14 +978,12 @@ class SortedInDisk(object):
         Note: If you consume full iterable then and delete_to_end is False, then you can to iterate more than one
         time and you need to delete temporal files by hand with clean.
 
-        Note: This is a wrapper of iter_with_key().
+        Note: This is a wrapper of items().
 
         :return: Sorted iterable of values
         """
-        def _iter_values(self):
-            for _, value in self.iter_with_key(delete_to_end=self.delete_to_end,
-                                               enable_multiprocessing=self.iter_multiprocessing,
-                                               queue_max_size=self.iter_m_queue_max_size):
+        def _iter_values(_self):
+            for _, value in _self.items():
                 yield value
         return _iter_values(self)
 
@@ -941,14 +994,12 @@ class SortedInDisk(object):
         Note: If you consume full iterable then and delete_to_end is False, then you can to iterate more than one
         time and you need to delete temporal files by hand with clean.
 
-        Note: This is a wrapper of iter_with_key().
+        Note: This is a wrapper of items().
 
         :return: Sorted iterable of keys sorted
         """
-        def _iter_keys(self):
-            for key, _ in self.iter_with_key(delete_to_end=self.delete_to_end,
-                                             enable_multiprocessing=self.iter_multiprocessing,
-                                             queue_max_size=self.iter_m_queue_max_size):
+        def _iter_keys(_self):
+            for key, _ in _self.items():
                 yield key
         return _iter_keys(self)
 
@@ -1000,7 +1051,7 @@ class SortedInDisk(object):
 
     def save_and_sort_multiprocess(self,
                                    it_values,
-                                   func_key_sort=None,
+                                   func_key=None,
                                    func_value=None,
                                    reverse=False,
 
@@ -1010,13 +1061,17 @@ class SortedInDisk(object):
                                    max_process=None,
                                    queue_max_size=1000,
 
-                                   ensure_space=False):
+                                   ensure_space=False,
+
+                                   size_bucket_list=None,
+                                   min_size_bucket_list=10,
+                                   max_size_bucket_list=None):
         """
         Consume a iterable to be sorted in multiprocess way.
         Take analysis in this iterable and save to disk (in temporal files).
 
         :param it_values: iterator of values
-        :param func_key_sort: function to extract the key of each value of it_values.
+        :param func_key: function to extract the key of each value of it_values.
             If None is full value of it_values. By default: None
         :param func_value: function to extract the value of each value of it_values.
             If None is full value of it_values. By default: None
@@ -1030,15 +1085,23 @@ class SortedInDisk(object):
         :param queue_max_size: max number of elements in queue. If None then is the max by default. By default: 1000
         :param ensure_space: True to ensure disk space but is slowly. If not space then process launch warning message
             and wait for space. If False, then get and IOException if not enough space
+        :param size_bucket_list: None to enable sensor size bucket list (require maxsize>0). If a number is defined
+                                 here then use this number to size_bucket_list and disable sensor. If maxsize<=0
+                                 and size_bucket_list==None then size_bucket_list is default to 1000; other wise,
+                                 if maxsize<=0 and size_bucket_list is defined, then use this number. By default: None
+        :param min_size_bucket_list: (only if sensor is enabled) min size bucket list.
+                                     Min == 1 and max == max_size_bucket_list - 1. By default: 10
+        :param max_size_bucket_list: (only if sensor is enabled) max size bucket list. If None is infinite.
+                                     By default: None
         :return: self
         """
         logging.debug("[ROOT START -> ppid:{} | pid:{}]".format(os.getppid(), os.getpid()))
 
-        if func_key_sort is None:
-            def func_key_sort_default(key):
+        if func_key is None:
+            def func_key_default(key):
                 return key
 
-            func_key_sort = func_key_sort_default
+            func_key = func_key_default
 
         if func_value is None:
             def func_value_default(value):
@@ -1054,10 +1117,11 @@ class SortedInDisk(object):
 
         self.set_dict_saved_info(dict_info)
 
-        if queue_max_size is None:
-            proxy_queue = multiprocessing.Queue()
-        else:
-            proxy_queue = multiprocessing.Queue(queue_max_size)
+        proxy_queue = QQueue(queue_max_size,
+                             size_bucket_list=size_bucket_list,
+                             min_size_bucket_list=min_size_bucket_list,
+                             max_size_bucket_list=max_size_bucket_list,
+                             logging_level=self.logging_level)
 
         self.join_multiprocess()
 
@@ -1067,61 +1131,57 @@ class SortedInDisk(object):
         proxy_start_event = multiprocessing.Event()
         proxy_start_event.clear()
 
-        try:
-            try:
-                first_value = next(it_values)
-            except TypeError:
-                it_values = (v for v in it_values)
-                first_value = next(it_values)
+        logging.debug("[ROOT INITIALIZE CHILDS -> ppid:{} | pid:{}]".format(os.getppid(), os.getpid()))
 
-            logging.debug("[ROOT INITIALIZE CHILDS -> ppid:{} | pid:{}]".format(os.getppid(), os.getpid()))
+        self.proxy_dict = self.manager.dict()
+        num_processors = multiprocessing.cpu_count() if max_process is None else max_process
+        for procesnum in range(0, num_processors):
 
-            self.proxy_dict = self.manager.dict()
-            for procesnum in range(0, multiprocessing.cpu_count() if max_process is None else max_process):
-
-                if dict_info["dict_ipid_tup_full_list_parts"] is None:
+            if dict_info["dict_ipid_tup_full_list_parts"] is None:
+                next_id_path_to_keys_sorted = 0
+            else:
+                try:
+                    next_id_path_to_keys_sorted = dict_info["dict_ipid_tup_full_list_parts"][procesnum][2]
+                except KeyError:
                     next_id_path_to_keys_sorted = 0
-                else:
-                    try:
-                        next_id_path_to_keys_sorted = dict_info["dict_ipid_tup_full_list_parts"][procesnum][2]
-                    except KeyError:
-                        next_id_path_to_keys_sorted = 0
 
-                process = multiprocessing.Process(target=_mprocess, args=(proxy_queue,
-                                                                          proxy_start_event,
-                                                                          proxy_end_event,
-                                                                          procesnum,
+            process = multiprocessing.Process(target=_mprocess, args=(proxy_queue,
+                                                                      proxy_start_event,
+                                                                      proxy_end_event,
+                                                                      procesnum,
 
-                                                                          self.dir_tmp_path,
-                                                                          self.proxy_dict,
+                                                                      self.dir_tmp_path,
+                                                                      self.proxy_dict,
 
-                                                                          count_insert_to_check,
-                                                                          max_process_size,
-                                                                          reverse,
-                                                                          next_id_path_to_keys_sorted,
+                                                                      count_insert_to_check,
+                                                                      max_process_size,
+                                                                      reverse,
+                                                                      next_id_path_to_keys_sorted,
 
-                                                                          ensure_space,
-                                                                          self.logging_level))
-                process.daemon = True
-                process.start()
-                self.dict_num_procceses[procesnum] = process
+                                                                      ensure_space,
+                                                                      self.logging_level))
+            process.daemon = True
+            process.start()
+            self.dict_num_procceses[procesnum] = process
 
-            logging.debug("[ROOT START DATA ITERATION -> ppid:{} | pid:{}]".format(os.getppid(), os.getpid()))
+        logging.debug("[ROOT START DATA ITERATION -> ppid:{} | pid:{}]".format(os.getppid(), os.getpid()))
 
-            gc.collect()
-            proxy_start_event.set()
+        gc.collect()
+        proxy_start_event.set()
 
-            count = 1
-            proxy_queue.put((func_key_sort(first_value), func_value(first_value)))
-            for count, value in enumerate(it_values, 2):
-                proxy_queue.put((func_key_sort(value), func_value(value)))
+        if func_key is None and func_value is None:
+            proxy_queue.put_iterable(((v, v) for v in it_values))
+        elif func_value is None:
+            proxy_queue.put_iterable(((func_key(v), v) for v in it_values))
+        elif func_key is None:
+            proxy_queue.put_iterable(((v, func_value(v)) for v in it_values))
+        else:
+            proxy_queue.put_iterable(((func_key(v), func_value(v)) for v in it_values))
 
-            logging.debug("[ROOT LINES PROCESED: {} -> ppid:{} | pid:{}]".format(count, os.getppid(), os.getpid()))
+        logging.debug("[ROOT LINES PROCESSED: ppid:{} | pid:{}]".format(os.getppid(), os.getpid()))
 
-            proxy_queue.close()
-            proxy_end_event.set()
-        except StopIteration:
-            pass
+        proxy_queue.end()
+        proxy_end_event.set()
 
         gc.collect()
         logging.debug("[ROOT END -> ppid:{} | pid:{}]".format(os.getppid(), os.getpid()))
@@ -1130,7 +1190,7 @@ class SortedInDisk(object):
 
     def save_and_sort(self,
                       it_values,
-                      func_key_sort=None,
+                      func_key=None,
                       func_value=None,
                       reverse=False,
 
@@ -1140,12 +1200,16 @@ class SortedInDisk(object):
                       max_process=None,
                       queue_max_size=1000,
 
-                      ensure_space=False):
+                      ensure_space=False,
+
+                      size_bucket_list=None,
+                      min_size_bucket_list=10,
+                      max_size_bucket_list=None):
         """
         Choose save_and_sort_multiprocess of save_and_sort_mono depend on max_process
 
         :param it_values: iterator of values
-        :param func_key_sort: function to extract the key of each value of it_values.
+        :param func_key: function to extract the key of each value of it_values.
             If None is full value of it_values. By default: None
         :param func_value: function to extract the value of each value of it_values.
             If None is full value of it_values. By default: None
@@ -1159,11 +1223,19 @@ class SortedInDisk(object):
         :param queue_max_size: max number of elements in queue. If None then is the max by default. By default: 1000
         :param ensure_space: True to ensure disk space but is slowly. If not space then process launch warning message
             and wait for space. If False, then get and IOException if not enough space
+        :param size_bucket_list: None to enable sensor size bucket list (require maxsize>0). If a number is defined
+                                 here then use this number to size_bucket_list and disable sensor. If maxsize<=0
+                                 and size_bucket_list==None then size_bucket_list is default to 1000; other wise,
+                                 if maxsize<=0 and size_bucket_list is defined, then use this number. By default: None
+        :param min_size_bucket_list: (only if sensor is enabled) min size bucket list.
+                                     Min == 1 and max == max_size_bucket_list - 1. By default: 10
+        :param max_size_bucket_list: (only if sensor is enabled) max size bucket list. If None is infinite.
+                                     By default: None
         :return:
         """
         if max_process is 0:
             self.save_and_sort_mono(it_values=it_values,
-                                    func_key_sort=func_key_sort,
+                                    func_key=func_key,
                                     func_value=func_value,
                                     reverse=reverse,
                                     count_insert_to_check=count_insert_to_check,
@@ -1171,20 +1243,27 @@ class SortedInDisk(object):
                                     ensure_space=ensure_space)
         else:
             self.save_and_sort_multiprocess(it_values=it_values,
-                                            func_key_sort=func_key_sort,
+                                            func_key=func_key,
                                             func_value=func_value,
                                             reverse=reverse,
                                             count_insert_to_check=count_insert_to_check,
                                             max_process_size=max_process_size,
                                             max_process=max_process,
                                             queue_max_size=queue_max_size,
-                                            ensure_space=ensure_space)
+                                            ensure_space=ensure_space,
+                                            size_bucket_list=size_bucket_list,
+                                            min_size_bucket_list=min_size_bucket_list,
+                                            max_size_bucket_list=max_size_bucket_list)
         return self
 
     def iter_with_key(self,
                       delete_to_end=True,
                       enable_multiprocessing=False,
-                      queue_max_size=1000):
+                      queue_max_size=1000,
+
+                      size_bucket_list=None,
+                      min_size_bucket_list=10,
+                      max_size_bucket_list=None):
         """
         Get a sorted iterable from disk to return tuples of key and sorted line, in each petition this get one
         sorted line.
@@ -1200,6 +1279,14 @@ class SortedInDisk(object):
             By default: False
         :param queue_max_size: (only if enable_multiprocessing is True) max number of elements in queue. If None
             then is the max by default. By default: 1000
+        :param size_bucket_list: None to enable sensor size bucket list (require maxsize>0). If a number is defined
+                         here then use this number to size_bucket_list and disable sensor. If maxsize<=0
+                         and size_bucket_list==None then size_bucket_list is default to 1000; other wise,
+                         if maxsize<=0 and size_bucket_list is defined, then use this number. By default: None
+        :param min_size_bucket_list: (only if sensor is enabled) min size bucket list.
+                                     Min == 1 and max == max_size_bucket_list - 1. By default: 10
+        :param max_size_bucket_list: (only if sensor is enabled) max size bucket list. If None is infinite.
+                                     By default: None
         :return None
         """
         dict_info = self.get_dict_saved_info()
@@ -1215,10 +1302,11 @@ class SortedInDisk(object):
         dict_ipid_tup_full_list_parts = dict_info["dict_ipid_tup_full_list_parts"]
 
         if enable_multiprocessing:
-            if queue_max_size is None:
-                proxy_queue_iter = multiprocessing.Queue()
-            else:
-                proxy_queue_iter = multiprocessing.Queue(queue_max_size)
+            proxy_queue_iter = QQueue(queue_max_size,
+                                      size_bucket_list=size_bucket_list,
+                                      min_size_bucket_list=min_size_bucket_list,
+                                      max_size_bucket_list=max_size_bucket_list,
+                                      logging_level=self.logging_level)
 
             proxy_start_event_iter = multiprocessing.Event()
             proxy_start_event_iter.clear()
@@ -1229,6 +1317,7 @@ class SortedInDisk(object):
             logging.debug("[ROOTG INITIALIZE CHILD -> ppid:{} | pid:{}]".format(os.getppid(), os.getpid()))
 
             process = multiprocessing.Process(target=_mprocess_iter, args=(proxy_queue_iter,
+                                                                           proxy_queue_iter.get_init_args(),
                                                                            proxy_start_event_iter,
                                                                            proxy_end_event_iter,
                                                                            dict_ipid_tup_full_list_parts,
